@@ -43,6 +43,12 @@ class TestURLHelper(WebHelpersTestCase):
         self.assertEqual("<form method=\"GET\" action=\"http://www.example.com\" class=\"button-to\"><div><input type=\"submit\" value=\"Hello\" /></div></form>",
             button_to("Hello", "http://www.example.com", method='GET'))
 
+    def test_button_to_with_img(self):
+        self.assertEqual('<form method="POST" action="/content/edit/3" class="button-to"><div><input alt="Edit" src="/images/icon_delete.gif" type="image" value="Edit" /></div></form>',
+                         button_to("Edit", url(action='edit', id=3), type='image', src='icon_delete.gif'))
+        self.assertEqual('<form method="POST" action="/content/submit/3" class="button-to"><div><input alt="Complete the form" src="/images/submit.png" type="image" value="Submit" /></div></form>',
+                         button_to("Submit", url(action='submit', id=3), type='image', src='submit', alt='Complete the form'))
+
     def test_link_tag_with_straight_url(self):
         self.assertEqual("<a href=\"http://www.example.com\">Hello</a>", link_to("Hello", "http://www.example.com"))
     
@@ -164,12 +170,12 @@ class TestURLHelper(WebHelpersTestCase):
                          mail_to("me@domain.com", "My email", encode = "javascript", replace_at = "(at)", replace_dot = "(dot)"))
 
     def test_current_page(self):
-        self.assertTrue(current_page('/test?test=webhelpers&framework=pylons'))
-        self.assertTrue(current_page(url('/test?test=webhelpers&framework=pylons')))
+        self.assertEqual(True, (current_page('/test?test=webhelpers&framework=pylons')))
+        self.assertEqual(True, current_page(url('/test?test=webhelpers&framework=pylons')))
 
     def test_current_url(self):
         self.assertEquals('/test?test=webhelpers&framework=pylons', current_url())
-        self.assertTrue(isinstance(current_url(), str))
+        self.assertEquals(True, isinstance(current_url(), str))
 
 if __name__ == '__main__':
     suite = [unittest.makeSuite(TestURLHelper)]
